==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/arrays/arr_abuse_status.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


/*
* array, warning, the id's must match the config file
* these arrays are used for dropdowns and lists in the html, typically as form
* input fields, hence the id's are inserted into the db and must match the
* config for database queries.
*
* if you do not understand this, do not change anything - what can break will break.
*
* tom calthrop 11th January 2004
*/

$lang['arr_abuse_status'][0] = 			"closed";
$lang['arr_abuse_status'][1] = 			"processing";
$lang['arr_abuse_status'][2] = 			"unallocated";

?>

==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/arrays/arr_abuse_status.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


/*
* array, warning, the id's must match the config file
* these arrays are used for dropdowns and lists in the html, typically as form
* input fields, hence the id's are inserted into the db and must match the
* config for database queries.
*
* if you do not understand this, do not change anything - what can break will break.
*
* tom calthrop 11th January 2004
*/

$lang['arr_abuse_status'][0] = 			"closed";
$lang['arr_abuse_status'][1] = 			"processing";
$lang['arr_abuse_status'][2] = 			"unallocated";

?>
